@@ -377,6 +377,14 @@ class Tagging(Rules):
                 if (not taxonomy.is_tag(t)):
                     log.warning("[Tagging] %s not in taxonomy" % t)
 
+    def build_synonymn_map(self):
+        """Build a map from dst to src set from Tagging"""
+        dst_map = {}
+        for src, dst_set in self._src_map.items():
+            for dst in dst_set:
+                dst_map.setdefault(dst, set()).add(src)
+        return dst_map
+
 class Expansion(Rules):
     """A rule where source different than destination and both in taxonomy"""
     def __init__(self, filepath):
@@ -416,13 +424,12 @@ class AvLabels:
  
            Checks if highest ranked CLASS tag contains "grayware"
            and is above a predefined threshold
-           Return:
-            True/False/None
+           It returns False unless it can determine it is PUP
         """
         threshold = 0.5
         # If no tags, return false
         if len(tag_pairs) < 1:
-            return None
+            return False
         max_ctr = tag_pairs[0][1]
         for (tag,ctr) in tag_pairs:
             (path, cat) = taxonomy.get_info(tag)
